@@ -14,6 +14,8 @@ LOGGER = getLogger("PyLav.LibConfigManager")
 
 
 class LibConfigManager:
+    __slots__ = ("_client", "_config_folder")
+
     def __init__(self, client: Client):
         self._client = client
         self._config_folder = CONFIG_DIR
@@ -75,7 +77,7 @@ class LibConfigManager:
         return LibConfigModel(id=1, bot=self.client.bot.user.id)
 
     def get_bot_db_version(self) -> BotVersion:
-        return BotVersion(bot=self._client.bot.user.id)
+        return BotVersion(id=self._client.bot.user.id)
 
     async def update_bot_dv_version(self, version: str) -> None:
-        await BotVersion(bot=self._client.bot.user.id).update_version(version)
+        await self.get_bot_db_version().update_version(version)
